==> mastapy-12.0.6.tar.gz: mastapy-12.0.6/mastapy/nodal_analysis/_61.py <==
﻿"""_61.py

FEMeshingOptions
"""


from typing import List

from mastapy.nodal_analysis import _58, _91, _62
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FE_MESHING_OPTIONS = python_net_import('SMT.MastaAPI.NodalAnalysis', 'FEMeshingOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('FEMeshingOptions',)


class FEMeshingOptions(_0.APIBase):
    """FEMeshingOptions

    This is a mastapy class.
    """

    TYPE = _FE_MESHING_OPTIONS

    def __init__(self, instance_to_wrap: 'FEMeshingOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def element_order(self) -> '_58.ElementOrder':
        """ElementOrder: 'ElementOrder' is the original name of this property."""

        temp = self.wrapped.ElementOrder

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_58.ElementOrder)(value) if value is not None else None

    @element_order.setter
    def element_order(self, value: '_58.ElementOrder'):
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ElementOrder = value

    @property
    def element_shape(self) -> '_91.VolumeElementShape':
        """VolumeElementShape: 'ElementShape' is the original name of this property."""

        temp = self.wrapped.ElementShape

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_91.VolumeElementShape)(value) if value is not None else None

    @element_shape.setter
    def element_shape(self, value: '_91.VolumeElementShape'):
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ElementShape = value

    @property
    def maximum_chord_height(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MaximumChordHeight' is the original name of this property."""

        temp = self.wrapped.MaximumChordHeight

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else 0.0

    @maximum_chord_height.setter
    def maximum_chord_height(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MaximumChordHeight = value

    @property
    def maximum_edge_altitude_ratio(self) -> 'float':
        """float: 'MaximumEdgeAltitudeRatio' is the original name of this property."""

        temp = self.wrapped.MaximumEdgeAltitudeRatio

        if temp is None:
            return 0.0

        return temp

    @maximum_edge_altitude_ratio.setter
    def maximum_edge_altitude_ratio(self, value: 'float'):
        self.wrapped.MaximumEdgeAltitudeRatio = float(value) if value is not None else 0.0

    @property
    def maximum_growth_rate(self) -> 'float':
        """float: 'MaximumGrowthRate' is the original name of this property."""

        temp = self.wrapped.MaximumGrowthRate

        if temp is None:
            return 0.0

        return temp

    @maximum_growth_rate.setter
    def maximum_growth_rate(self, value: 'float'):
        self.wrapped.MaximumGrowthRate = float(value) if value is not None else 0.0

    @property
    def maximum_spanning_angle(self) -> 'float':
        """float: 'MaximumSpanningAngle' is the original name of this property."""

        temp = self.wrapped.MaximumSpanningAngle

        if temp is None:
            return 0.0

        return temp

    @maximum_spanning_angle.setter
    def maximum_spanning_angle(self, value: 'float'):
        self.wrapped.MaximumSpanningAngle = float(value) if value is not None else 0.0

    @property
    def minimum_element_size(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MinimumElementSize' is the original name of this property."""

        temp = self.wrapped.MinimumElementSize

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else 0.0

    @minimum_element_size.setter
    def minimum_element_size(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MinimumElementSize = value

    @property
    def minimum_triangle_angle(self) -> 'float':
        """float: 'MinimumTriangleAngle' is the original name of this property."""

        temp = self.wrapped.MinimumTriangleAngle

        if temp is None:
            return 0.0

        return temp

    @minimum_triangle_angle.setter
    def minimum_triangle_angle(self, value: 'float'):
        self.wrapped.MinimumTriangleAngle = float(value) if value is not None else 0.0

    @property
    def preserve_edge_angle(self) -> 'float':
        """float: 'PreserveEdgeAngle' is the original name of this property."""

        temp = self.wrapped.PreserveEdgeAngle

        if temp is None:
            return 0.0

        return temp

    @preserve_edge_angle.setter
    def preserve_edge_angle(self, value: 'float'):
        self.wrapped.PreserveEdgeAngle = float(value) if value is not None else 0.0

    @property
    def preserve_node_angle(self) -> 'float':
        """float: 'PreserveNodeAngle' is the original name of this property."""

        temp = self.wrapped.PreserveNodeAngle

        if temp is None:
            return 0.0

        return temp

    @preserve_node_angle.setter
    def preserve_node_angle(self, value: 'float'):
        self.wrapped.PreserveNodeAngle = float(value) if value is not None else 0.0

    @property
    def meshing_problems(self) -> 'List[_62.FEMeshingProblem]':
        """List[FEMeshingProblem]: 'MeshingProblems' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshingProblems

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result

==> mastapy-13.0a2.tar.gz: mastapy-13.0a2/mastapy/nodal_analysis/_61.py <==
﻿"""_61.py

FEMeshingOptions
"""
from typing import List

from mastapy.nodal_analysis import _58, _91, _62
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_FE_MESHING_OPTIONS = python_net_import('SMT.MastaAPI.NodalAnalysis', 'FEMeshingOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('FEMeshingOptions',)


class FEMeshingOptions(_0.APIBase):
    """FEMeshingOptions

    This is a mastapy class.
    """

    TYPE = _FE_MESHING_OPTIONS

    class _Cast_FEMeshingOptions:
        """Special nested class for casting FEMeshingOptions to subclasses."""

        def __init__(self, parent: 'FEMeshingOptions'):
            self._parent = parent

        @property
        def shaft_fe_meshing_options(self):
            from mastapy.nodal_analysis import _84
            
            return self._parent._cast(_84.ShaftFEMeshingOptions)

        @property
        def electric_machine_mechanical_analysis_meshing_options(self):
            from mastapy.electric_machines import _1256
            
            return self._parent._cast(_1256.ElectricMachineMechanicalAnalysisMeshingOptions)

        @property
        def electric_machine_meshing_options(self):
            from mastapy.electric_machines import _1257
            
            return self._parent._cast(_1257.ElectricMachineMeshingOptions)

        @property
        def electric_machine_meshing_options_base(self):
            from mastapy.electric_machines import _1258
            
            return self._parent._cast(_1258.ElectricMachineMeshingOptionsBase)

        @property
        def fe_meshing_options(self) -> 'FEMeshingOptions':
            return self._parent

        def __getattr__(self, name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = ''.join(n.capitalize() for n in name.split('_'))
                raise CastException(f'Detected an invalid cast. Cannot cast to type "{class_name}"') from None

    def __init__(self, instance_to_wrap: 'FEMeshingOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def element_order(self) -> '_58.ElementOrder':
        """ElementOrder: 'ElementOrder' is the original name of this property."""

        temp = self.wrapped.ElementOrder

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, _58.ElementOrder)
        return constructor.new_from_mastapy_type(_58.ElementOrder)(value) if value is not None else None

    @element_order.setter
    def element_order(self, value: '_58.ElementOrder'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value, _58.ElementOrder.type_())
        self.wrapped.ElementOrder = value

    @property
    def element_shape(self) -> '_91.VolumeElementShape':
        """VolumeElementShape: 'ElementShape' is the original name of this property."""

        temp = self.wrapped.ElementShape

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, _91.VolumeElementShape)
        return constructor.new_from_mastapy_type(_91.VolumeElementShape)(value) if value is not None else None

    @element_shape.setter
    def element_shape(self, value: '_91.VolumeElementShape'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value, _91.VolumeElementShape.type_())
        self.wrapped.ElementShape = value

    @property
    def maximum_chord_height(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MaximumChordHeight' is the original name of this property."""

        temp = self.wrapped.MaximumChordHeight

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else 0.0

    @maximum_chord_height.setter
    def maximum_chord_height(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MaximumChordHeight = value

    @property
    def maximum_edge_altitude_ratio(self) -> 'float':
        """float: 'MaximumEdgeAltitudeRatio' is the original name of this property."""

        temp = self.wrapped.MaximumEdgeAltitudeRatio

        if temp is None:
            return 0.0

        return temp

    @maximum_edge_altitude_ratio.setter
    def maximum_edge_altitude_ratio(self, value: 'float'):
        self.wrapped.MaximumEdgeAltitudeRatio = float(value) if value else 0.0

    @property
    def maximum_growth_rate(self) -> 'float':
        """float: 'MaximumGrowthRate' is the original name of this property."""

        temp = self.wrapped.MaximumGrowthRate

        if temp is None:
            return 0.0

        return temp

    @maximum_growth_rate.setter
    def maximum_growth_rate(self, value: 'float'):
        self.wrapped.MaximumGrowthRate = float(value) if value else 0.0

    @property
    def maximum_spanning_angle(self) -> 'float':
        """float: 'MaximumSpanningAngle' is the original name of this property."""

        temp = self.wrapped.MaximumSpanningAngle

        if temp is None:
            return 0.0

        return temp

    @maximum_spanning_angle.setter
    def maximum_spanning_angle(self, value: 'float'):
        self.wrapped.MaximumSpanningAngle = float(value) if value else 0.0

    @property
    def minimum_element_size(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MinimumElementSize' is the original name of this property."""

        temp = self.wrapped.MinimumElementSize

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else 0.0

    @minimum_element_size.setter
    def minimum_element_size(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MinimumElementSize = value

    @property
    def minimum_triangle_angle(self) -> 'float':
        """float: 'MinimumTriangleAngle' is the original name of this property."""

        temp = self.wrapped.MinimumTriangleAngle

        if temp is None:
            return 0.0

        return temp

    @minimum_triangle_angle.setter
    def minimum_triangle_angle(self, value: 'float'):
        self.wrapped.MinimumTriangleAngle = float(value) if value else 0.0

    @property
    def preserve_edge_angle(self) -> 'float':
        """float: 'PreserveEdgeAngle' is the original name of this property."""

        temp = self.wrapped.PreserveEdgeAngle

        if temp is None:
            return 0.0

        return temp

    @preserve_edge_angle.setter
    def preserve_edge_angle(self, value: 'float'):
        self.wrapped.PreserveEdgeAngle = float(value) if value else 0.0

    @property
    def preserve_node_angle(self) -> 'float':
        """float: 'PreserveNodeAngle' is the original name of this property."""

        temp = self.wrapped.PreserveNodeAngle

        if temp is None:
            return 0.0

        return temp

    @preserve_node_angle.setter
    def preserve_node_angle(self, value: 'float'):
        self.wrapped.PreserveNodeAngle = float(value) if value else 0.0

    @property
    def meshing_problems(self) -> 'List[_62.FEMeshingProblem]':
        """List[FEMeshingProblem]: 'MeshingProblems' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshingProblems

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result

    @property
    def cast_to(self) -> 'FEMeshingOptions._Cast_FEMeshingOptions':
        return self._Cast_FEMeshingOptions(self)
